DirectoryScrewdriver extension

Provides extensions for Directory.

on

Methods

createIfMissing({bool recursive = false}) → Future<Directory>

Available on Directory, provided by the DirectoryScrewdriver extension

Creates the directory if it does not exist. Returns the directory instance.
createIfMissingSync({bool recursive = false}) → void

Available on Directory, provided by the DirectoryScrewdriver extension

Synchronously creates the directory if it does not exist.
deleteIfExists({bool recursive = false}) → Future<FileSystemEntity?>

Available on Directory, provided by the DirectoryScrewdriver extension

Deletes the directory and its contents if it exists.
deleteIfExistsSync({bool recursive = false}) → void

Available on Directory, provided by the DirectoryScrewdriver extension

Synchronously deletes the directory and its contents if it exists.
file(String fileName) → File

Available on Directory, provided by the DirectoryScrewdriver extension

Creates a File instance with the given fileName in this directory.
subDir(String part1, [String? part2, String? part3, String? part4, String? part5]) → Directory

Available on Directory, provided by the DirectoryScrewdriver extension

Creates a Directory instance representing a subdirectory in this directory.